#
# spec file for package pijul
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dlver   1.0.0-beta.9

Name:           pijul
Version:        1.0.0~beta.9
Release:        1.3
Summary:        Distributed version control system based on a theory of patches
License:        GPL-2.0-only
Group:          Development/Tools/Version Control
URL:            https://pijul.org/
Source0:        https://crates.io/api/v1/crates/pijul/%{dlver}/download#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(openssl)

%description
Pijul is a distributed version control system. Its distinctive feature is to be
based on a theory of patches, which makes it really distributed.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       %{name} = %{version}
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       %{name} = %{version}
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       %{name} = %{version}
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1 -n %{name}-%{dlver}

%build
%{cargo_build}

%check
%{cargo_test}

%install
%{cargo_install}
for sh in bash zsh fish; do
  ./target/release/%{name} completion $sh > %{name}.$sh
done
install -Dm644 %{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 %{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm644 %{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files
%{_bindir}/pijul

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Mon May 27 2024 Joshua Smith <smolsheep@opensuse.org>
- Enabled tests
- Removed unneeded completion conflicts and repackaged completions
- Cleaned BuildRequires of unneeded references
- Adjust packaging to modern rust standards:
  * manual vendoring -> cargo_vendor
  * cargo.toml is now part of the vendoring
  * setup -> autosetup
  * cargo_build and cargo_install macros
- Update to upstream version 1.0.0-beta.9:
  * No upstream changelog provided. Version tags aren't made to
    easily pull a rich changelog.
    See:
  - https://nest.pijul.com/pijul/pijul/changes
  - https://nest.pijul.com/pijul/pijul:main/YUJV2OHL2JRZA.EUAAA
* Wed Dec 20 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.8.
* Mon Sep  4 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.6.
* Thu Jun  1 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.5.
- This version uses hyper 0.14.26 and h2 0.3.19, preventing CVE-2023-26964
  (bsc#1210361).
* Tue Mar  7 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.4.
- This version uses hyper 0.14.24, which prevents CVE-2022-31394
  (bsc#1208559).
* Mon May  9 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.2:
  * Improve "pijul key" documentation.
  * "pijul pull" does not open $EDITOR anymore when given a list
    of changes.
  * Fix a bug with name conflicts.
  * Fix a few panic/unwraps problems.
  * Fix a bug where a zombile file could be deleted by
    "pijul unrecord" but its contents would stay zombie.
  * Update regex dependency to prevent CVE-2022-24713
    (bsc#1196972).
- Changes from version 1.0.0-beta.1:
  * Fixed a failed assertion in the patch text format.
  * Fixed a "merged vertices" bug when moving and editing them in
    the same patch.
* Tue Jan 25 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta:
  * Add --force to "add" to include ignored files.
  * Fix conflict identifiers.
  * Remove the --tag option from "push/pull".
  * Fix "log" filters.
- Changes from version 1.0.0-alpha.57:
  * Add support for tags.
  * Fix path crashes related to the non-null roots.
  * Prioritise moving a file over undeletion.
  * Show the correct paths in recursive file deletions.
  * Add --force to "reset/switch" to ignore name conflicts.
  * Avoid printing multiple names conflicts more than once.
  * Better error message when pushing to a non-existent local
    channel.
  * Fix log --filters, along with performance improvements.
* Tue Dec 21 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.56:
  * Re-implement change printing and parsing.
  * Add a root inode (initial support for submodules).
  * Fix a deprecation warning in ed25519-dalek.
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Sun Oct 24 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.55:
  * Better estimation of the maximum number of open patches that
    Pijul can keep.
  * Proper escaping of UTF-8 filenames in the patch text format.
  * Add patch filtering to "git log".
  * Add JSON output for "git log".
  * "pijul init" does not modify already existing .ignore files.
  * Improve detection of binary files.
* Tue Sep 28 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.54:
  * Improve push/pull reporting.
  * Fix a panic when outputting zombie folders.
  * Better computation of progress bars width.
  * Pushing/pulling from/to Nest discussions again.
  * Allow remotes to have different push and pull addresses.
  * Correct reporting of permission errors on external subcommands.
  * Add a .ignore file when initializing a repository containing a
    list of commonly ignored entries. See the "--kind" flag
    of the "pijul init" subcommand.
- Changes from version 1.0.0-alpha.53:
  * Fix newline issues with OpenSSH which caused clone via SSH
    to hang.
  * Do not remove untracked files when outputting.
  * Make recursive directory remove optional.
  * Add an option to limit the output size of "pijul log".
  * Make "pijul diff --short" more informative.
  * Fix "pijul diff --untracked".
  * Use the change time in addition to the modified time when
    detecting untouched files.
  * Print modifications only once in "pijul diff".
  * Do not compute the entire diff if only "--json --untracked"
    is wanted.
  * Unrecord the pending patch when pulling, in the special
    case that there is no thing to download.
  * Add a progress bar to "git push".
  * Fix "addition error" on "pijul git".
  * Better "pijul git" error message when recording.
* Tue Jul 20 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.52.
* Wed Mar 31 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.48.
* Tue Feb 16 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.38.
* Thu Jan 21 2021 Jan Engelhardt <jengelh@inai.de>
- Avoid bashisms in build recipe.
* Wed Jan 20 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.36.
* Tue Dec 22 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.24.
* Tue Dec  8 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.21.
- Enable 'Git' support (allow to import a Git repository into
  a Pijul one).
* Sun Dec  6 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.17.
* Fri Dec  4 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.15.
* Thu Aug 20 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Avoid build error for ppc64le as reported by boo#1175502
* Wed Sep  4 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream release 0.12.2.
- Add completion support for Bash, Zsh and Fish shells.
- Remove the README.md file because it is not included in the
  tarball anymore.
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and metadata redundancies from descriptions.
- Remove duplicate %%setup call.
* Thu Aug 22 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.12.0.
